//! Library that provides definitions for daemon related features in streamduck
pub mod socket;
pub mod core_manager;
pub mod config;